@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 
+import atexit
 import logging
 
 from pprint import pformat
@@ -11,6 +12,7 @@ from celery.bin.base import Command
 from . import settings
 from .app import Flower
 
+
 define("port", default=5555, help="run on the given port", type=int)
 define("address", default='', help="run on the given address", type=str)
 define("debug", default=False, help="run in debug mode", type=bool)
@@ -18,8 +20,16 @@ define("inspect", default=True, help="inspect workers", type=bool)
 define("inspect_timeout", default=1000, type=float,
        help="inspect timeout (in milliseconds)")
 define("auth", default='', type=str,
-       help="comma separated list of emails to grant access")
+       help="regexp  of emails to grant access")
+define("basic_auth", type=str, default=None,
+       help="colon separated user-password to enable basic auth")
 define("url_prefix", type=str, help="base url prefix")
+define("max_tasks", type=int, default=10000,
+       help="maximum number of tasks to keep in memory (default 10000)")
+define("db", type=str, default='flower.db', help="flower database file")
+define("persistent", type=bool, default=False, help="enable persistent mode")
+define("broker_api", type=str, default=None,
+        help="inspect broker e.g. http://guest:guest@localhost:15672/api/")
 
 
 class FlowerCommand(Command):
@@ -28,8 +38,8 @@ class FlowerCommand(Command):
         app_settings = settings.APP_SETTINGS
         argv = filter(self.flower_option, argv)
         parse_command_line([prog_name] + argv)
-        auth = map(str.strip, options.auth.split(',')) if options.auth else []
         app_settings['debug'] = options.debug
+
         if options.url_prefix:
             prefix = options.url_prefix.strip('/')
             app_settings['static_url_prefix'] = '/{0}/static/'.format(prefix)
@@ -37,7 +47,11 @@ class FlowerCommand(Command):
             settings.URL_PREFIX = prefix
         settings.CELERY_INSPECT_TIMEOUT = options.inspect_timeout
 
-        flower = Flower(celery_app=self.app, auth=auth, **app_settings)
+        # Monkey-patch to support Celery 2.5.5
+        self.app.connection = self.app.broker_connection
+        flower = Flower(celery_app=self.app, options=options,
+                        **app_settings)
+        atexit.register(flower.stop)
 
         logging.info('Visit me at http://%s:%s' %
                     (options.address or 'localhost', options.port))
@@ -45,8 +59,7 @@ class FlowerCommand(Command):
         logging.debug('Settings: %s' % pformat(app_settings))
 
         try:
-            flower.start(options.port, address=options.address,
-                         inspect=options.inspect)
+            flower.start()
         except (KeyboardInterrupt, SystemExit):
             pass
 
