@@ -221,18 +221,21 @@ var flower = (function () {
         var workername = $('#workername').text(),
             taskname = $(event.target).closest("tr").children("td:eq(0)").text(),
             type = $(event.target).html().toLowerCase(),
-            timeout = $(event.target).siblings().closest("input").val();
+            timeout = $(event.target).siblings().closest("input").val(),
+            data = {};
 
         taskname = taskname.split(' ')[0]; // removes [rate_limit=xxx]
 
+        console.log(type);
+
+        data.taskname = taskname;
+        data[type] = timeout;
+
         $.ajax({
             type: 'POST',
             url: url_prefix() + '/api/task/timeout/' + workername,
             dataType: 'json',
-            data: {
-                'taskname': taskname,
-                type: timeout,
-            },
+            data: data,
             success: function (data) {
                 show_success_alert(data.message);
             },
@@ -350,7 +353,6 @@ var flower = (function () {
         event.stopPropagation();
 
         $('#task-filter-form').each(function () {
-            $(this).find('INPUT:text').val('');
             $(this).find('SELECT').val('');
         });
 
@@ -465,6 +467,11 @@ var flower = (function () {
             };
         }
 
+        //https://github.com/twitter/bootstrap/issues/1768
+        var shiftWindow = function() { scrollBy(0, -50) };
+        if (location.hash) shiftWindow();
+        window.addEventListener("hashchange", shiftWindow);
+
         // Make bootstrap tabs persistent
         $(document).ready(function () {
             if (location.hash !== '') {
@@ -479,9 +486,12 @@ var flower = (function () {
         if ($(location).attr('pathname') === url_prefix() + '/monitor') {
             var sts = current_unix_time(),
                 fts = current_unix_time(),
+                tts = current_unix_time(),
                 updateinterval = 3000,
                 succeeded_graph = null,
-                failed_graph = null;
+                failed_graph = null,
+                time_graph = null,
+                broker_graph = null;
 
             $.ajax({
                 type: 'GET',
@@ -502,6 +512,25 @@ var flower = (function () {
                 },
             });
 
+            $.ajax({
+                type: 'GET',
+                url: url_prefix() + '/monitor/completion-time',
+                data: {lastquery: current_unix_time()},
+                success: function (data) {
+                    time_graph = create_graph(data, '-time');
+                    time_graph.update();
+
+                    time_graph.series.setTimeInterval(updateinterval);
+                    setInterval(function () {
+                        update_graph(time_graph,
+                                     url_prefix() + '/monitor/completion-time',
+                                     tts);
+                        tts = current_unix_time();
+                    }, updateinterval);
+
+                },
+            });
+
             $.ajax({
                 type: 'GET',
                 url: url_prefix() + '/monitor/failed-tasks',
@@ -521,6 +550,21 @@ var flower = (function () {
                 },
             });
 
+            $.ajax({
+                type: 'GET',
+                url: url_prefix() + '/monitor/broker',
+                success: function (data) {
+                    broker_graph = create_graph(data, '-broker');
+                    broker_graph.update();
+
+                    broker_graph.series.setTimeInterval(updateinterval);
+                    setInterval(function () {
+                        update_graph(broker_graph,
+                                     url_prefix() + '/monitor/broker');
+                    }, updateinterval);
+
+                },
+            });
 
         }
 
