@@ -12,6 +12,10 @@ from .views.tasks import (
     TasksView,
 )
 
+from .views.broker import (
+    BrokerView,
+)
+
 from .views import auth
 
 from .api import events
@@ -27,6 +31,8 @@ from .views.monitor import (
     Monitor,
     SucceededTaskMonitor,
     FailedTaskMonitor,
+    TimeToCompletionMonitor,
+    BrokerMonitor,
 )
 
 
@@ -41,6 +47,7 @@ handlers = [
     (r"/worker/(.+)", WorkerView),
     (r"/task/(.+)", TaskView),
     (r"/tasks", TasksView),
+    (r"/broker", BrokerView),
     # Worker API
     (r"/api/workers", workers.ListWorkers),
     (r"/api/worker/shutdown/(.+)", control.WorkerShutDown),
@@ -72,6 +79,8 @@ handlers = [
     (r"/monitor", Monitor),
     (r"/monitor/succeeded-tasks", SucceededTaskMonitor),
     (r"/monitor/failed-tasks", FailedTaskMonitor),
+    (r"/monitor/completion-time", TimeToCompletionMonitor),
+    (r"/monitor/broker", BrokerMonitor),
     # Static
     (r"/static/(.*)", StaticFileHandler,
      {"path": APP_SETTINGS['static_path']}),
