@@ -1,14 +1,16 @@
 from __future__ import absolute_import
 
+import re
 import inspect
 import traceback
 
 from urlparse import urljoin
+from base64 import b64decode
 
 import tornado
 
 from .. import settings
-from ..utils import template
+from ..utils import template, bugreport
 
 
 class BaseHandler(tornado.web.RequestHandler):
@@ -38,7 +40,12 @@ class BaseHandler(tornado.web.RequestHandler):
 
             self.render('error.html',
                         status_code=status_code,
-                        error_trace=error_trace)
+                        error_trace=error_trace,
+                        bugreport=bugreport())
+        elif status_code == 401:
+            self.set_status(status_code)
+            self.set_header('WWW-Authenticate', 'Basic realm="flower"')
+            self.finish('Access denied')
         else:
             message = None
             if 'exc_info' in kwargs and\
@@ -49,13 +56,26 @@ class BaseHandler(tornado.web.RequestHandler):
             self.set_status(status_code)
 
     def get_current_user(self):
+        # Basic Auth
+        basic_auth = self.application.basic_auth
+        if basic_auth:
+            auth_header = self.request.headers.get("Authorization", "")
+            try:
+                basic, credentials = auth_header.split()
+                credentials = b64decode(credentials)
+                if basic != 'Basic' or credentials != basic_auth:
+                    raise tornado.web.HTTPError(401)
+            except ValueError:
+                raise tornado.web.HTTPError(401)
+
+        # Google OpenID
         if not self.application.auth:
             return True
         user = self.get_secure_cookie('user')
-        if user and user in self.application.auth:
+        if user and re.search(self.application.auth, user):
             return user
         else:
-            return None
+            return
 
     def absolute_url(self, url):
         base = "{0}://{1}/".format(self.request.protocol, self.request.host)
